<?php

namespace Drupal\teamleader_contact;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\teamleader\TeamleaderApiInterface;
use Nascom\TeamleaderApiClient\Entity\Contact;

/**
 * Service to integrate Teamleader with Drupal core Contact module.
 */
class TeamleaderContact implements TeamleaderContactInterface {

  use StringTranslationTrait;

  /**
   * The Teamleader API client.
   *
   * @var \Nascom\TeamleaderApiClient\Http\ApiClient\ApiClient
   */
  protected $teamleaderClient;

  /**
   * Constructs a TeamleaderContact class.
   *
   * @param \Drupal\teamleader\TeamleaderApiInterface $teamleader_api
   *   The Teamleader API service.
   */
  public function __construct(TeamleaderApiInterface $teamleader_api) {
    $this->teamleaderClient = $teamleader_api->getClient();
  }

  /**
   * {@inheritdoc}
   */
  public function addContactToTeamleader(array $form, FormStateInterface &$form_state) {
    // Get the Teamleader Contact Repository.
    /** @var \Nascom\TeamleaderApiClient\Repository\ContactRepository $contactRepository */
    $contactRepository = $this->teamleaderClient->getContactRepository();
    $name = explode(" ", $form_state->getValue('name'));

    // Create a contact.
    $contact_variables = [
      'first_name' => array_shift($name),
      'last_name' => implode(" ", $name),
      'emails' => [
        [
          'type' => 'primary',
          'email' => $form_state->getValue('mail'),
        ],
      ],
      'remarks' => $this->t('Website contact form'),
      'marketing_mails_consent' => FALSE,
    ];
    $contact = new Contact($contact_variables);
    try {
      $contactRepository->addContact($contact);
    }
    catch (\Exception $ex) {
      drupal_set_message($ex->getMessage());
    }
  }

}
